PyFunction class

Annotation for a dart function to automatically create the python bindings

Work in progress

Constructors

PyFunction({required String module, String? name})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
module → String
The name of the python module the function is contained within
final
name → String?
The name of the python function
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited